==> cv-library-react-web-0.1.20.tgz: package/src/components/DataTableFloatingFilter/DataTableFloatingFilter.js <==
import React, { useState } from 'react';
import * as PropTypes from 'prop-types';

import TextField, { INPUT_TYPES } from '../TextField/TextField';
import Toggle from '../Toggle/Toggle';
import DateTimePicker, { DATE_TYPES, DATE_VIEWS } from '../DateTimePicker/DateTimePicker';
import DropDown from '../DropDown/DropDown';

const filterByStringOptions = [
    {
        value: 'equals',
        label: 'Equals',
    },
    {
        value: 'notEqual',
        label: 'Not Equals',
    },
    {
        value: 'contains',
        label: 'Contains',
    },
    {
        value: 'notContains',
        label: 'Not Contains',
    },
    {
        value: 'startsWith',
        label: 'Starts With',
    },
    {
        value: 'endsWith',
        label: 'Ends With',
    },
];
const filterByOptions = [
    {
        value: 'equals',
        label: 'Equals',
    },
    {
        value: 'greaterThan',
        label: 'Greater than',
    },
    {
        value: 'lessThan',
        label: 'Less than',
    },
    {
        value: 'notEqual',
        label: 'Not equal',
    },
    {
        value: 'inRange',
        label: 'In range',
    },
];

const DataTableFloatingFilter = (props) => {
    console.log('DATA TABLE FLOATING FILTER PROPS: ', props); // eslint-disable-line

    const {
        column,
        onApplyFilters,
        filterTypes: FILTER_TYPES,
    } = props;
    const {
        colDef,
    } = column;
    const {
        field,
        filterType,
    } = colDef;
    const [
        filters,
        setFilters,
    ] = useState({});
    const type = filterType.toUpperCase();

    // Default to text input type
    let textFieldType = INPUT_TYPES.TEXT;
    let stringCriteria = filterByStringOptions;

    // Default to DateTime date input type, format and views
    let dateFieldType = DATE_TYPES.DATETIME;
    let dateFieldFormat = 'M/dd/yy, h:mm a';
    let dateTimeViews = [
        DATE_VIEWS.DATE,
        DATE_VIEWS.HOURS,
        DATE_VIEWS.MINUTES,
        DATE_VIEWS.YEAR,
    ];
    const useRange = filters[field] && filters[field].criteria === 'inRange';

    switch (type) {
        case FILTER_TYPES.BOOLEAN:
            return (
                <Toggle
                    checked={ !!filters[field] || false }
                    onChange={ (event) => {
                        const {
                            currentTarget,
                        } = event;
                        const {
                            checked,
                        } = currentTarget;
                        setFilters({
                            ...filters,
                            [field]: checked,
                        });
                        if (onApplyFilters) {
                            onApplyFilters(field, checked);
                        }
                    } } />
            );

        case FILTER_TYPES.DATE:
            if (type === FILTER_TYPES.DATE) {
                dateFieldType = DATE_TYPES.DATE;
                dateFieldFormat = 'M/dd/yy';
                dateTimeViews = [
                    DATE_VIEWS.DATE,
                    DATE_VIEWS.YEAR,
                ];
            }
        // eslint-disable-next-line no-fallthrough
        case FILTER_TYPES.YEAR:
            if (type === FILTER_TYPES.YEAR) {
                dateFieldType = DATE_TYPES.DATE;
                dateFieldFormat = 'yyyy';
                dateTimeViews = [ DATE_VIEWS.YEAR ];
            }
        // eslint-disable-next-line no-fallthrough
        case FILTER_TYPES.TIME:
            if (type === FILTER_TYPES.TIME) {
                dateFieldType = DATE_TYPES.TIME;
                dateFieldFormat = 'h:mm a';
                dateTimeViews = [
                    DATE_VIEWS.HOURS,
                    DATE_VIEWS.MINUTES,
                ];
            }
        // eslint-disable-next-line no-fallthrough
        case FILTER_TYPES.DATETIME:
            return (
                <div style={ {
                    display: 'flex',
                    flexDirection: 'column',
                } }>
                    <DropDown
                        items={ filterByOptions }
                        onChange={ (event, props) => {
                            const {
                                target,
                            } = event;
                            const {
                                value,
                            } = target;
                            const {
                                text,
                            } = props;
                            const newFilters = {
                                ...filters,
                            };
                            newFilters[field] = {
                                ...newFilters[field],
                                criteria: value,
                                text,
                            };
                            setFilters(newFilters);
                            if (onApplyFilters) {
                                onApplyFilters(field, newFilters[field]);
                            }
                        } }
                        renderValue={ (value) => (value || 'Filter type...') }
                        renderItem={ (MenuItem, item) => (
                            <MenuItem
                                value={ item.value }
                                text={ item.label }
                                key={ item.value } />
                        ) }
                        value={ (filters[field] && filters[field].text) || '' } />
                    <DateTimePicker
                        emptyLabel={ useRange ? 'Filter from...' : 'Filter date...' }
                        selectedDate={ useRange ? (filters[field].valueFrom || null) : ((filters[field] && filters[field].value) || null) }
                        onChange={ (value) => {
                            const newFilters = {
                                ...filters,
                            };
                            if (useRange) {
                                newFilters[field] = {
                                    ...newFilters[field],
                                    valueFrom: value,
                                };
                            }
                            else {
                                newFilters[field] = {
                                    ...newFilters[field],
                                    value,
                                };
                            }
                            setFilters(newFilters);
                            if (onApplyFilters) {
                                onApplyFilters(field, newFilters[field]);
                            }
                        } }
                        format={ dateFieldFormat }
                        mode={ dateFieldType }
                        views={ dateTimeViews } />
                    { useRange &&
                        <DateTimePicker
                            emptyLabel="Filter to..."
                            selectedDate={ (filters[field] && filters[field].valueTo) || null }
                            onChange={ (value) => {
                                const newFilters = {
                                    ...filters,
                                };
                                if (useRange) {
                                    newFilters[field] = {
                                        ...newFilters[field],
                                        valueTo: value,
                                    };
                                }
                                else {
                                    newFilters[field] = {
                                        ...newFilters[field],
                                        value,
                                    };
                                }
                                setFilters(newFilters);
                                if (onApplyFilters) {
                                    onApplyFilters(field, newFilters[field]);
                                }
                            } }
                            format={ dateFieldFormat }
                            mode={ dateFieldType }
                            views={ dateTimeViews } />
                    }
                </div>
            );

        case FILTER_TYPES.DECIMAL:
            if (type === FILTER_TYPES.DECIMAL) {
                textFieldType = INPUT_TYPES.NUMBER;
                stringCriteria = filterByOptions;
            }
        // eslint-disable-next-line no-fallthrough
        case FILTER_TYPES.INTEGER:
            if (type === FILTER_TYPES.INTEGER) {
                textFieldType = INPUT_TYPES.NUMBER;
                stringCriteria = filterByOptions;
            }
        // eslint-disable-next-line no-fallthrough
        case FILTER_TYPES.STRING:
            return (
                <div style={ {
                    display: 'flex',
                    flexDirection: 'column',
                } }>
                    <DropDown
                        items={ stringCriteria }
                        onChange={ (event, props) => {
                            const {
                                target,
                            } = event;
                            const {
                                value,
                            } = target;
                            const {
                                text,
                            } = props;
                            const newFilters = {
                                ...filters,
                            };
                            newFilters[field] = {
                                ...newFilters[field],
                                criteria: value,
                                text,
                            };
                            setFilters(newFilters);
                            if (onApplyFilters) {
                                onApplyFilters(field, newFilters[field]);
                            }
                        } }
                        renderValue={ (value) => (value || 'Filter type...') }
                        renderItem={ (MenuItem, item) => (
                            <MenuItem
                                value={ item.value }
                                text={ item.label }
                                key={ item.value } />
                        ) }
                        value={ (filters[field] && filters[field].text) || '' } />
                    <TextField
                        placeholder={ useRange ? 'Filter from...' : 'Filter text...' }
                        type={ textFieldType }
                        onChange={ (event) => {
                            const {
                                currentTarget,
                            } = event;
                            const {
                                value,
                            } = currentTarget;
                            const newFilters = {
                                ...filters,
                            };
                            if (useRange) {
                                newFilters[field] = {
                                    ...newFilters[field],
                                    valueFrom: value,
                                };
                            }
                            else {
                                newFilters[field] = {
                                    ...newFilters[field],
                                    value,
                                };
                            }
                            setFilters(newFilters);
                            if (onApplyFilters) {
                                onApplyFilters(field, newFilters[field]);
                            }
                        } }
                        value={ useRange ? (filters[field].valueFrom || '') : ((filters[field] && filters[field].value) || '') } />
                    { useRange &&
                        <TextField
                            placeholder="Filter to..."
                            type={ textFieldType }
                            onChange={ (event) => {
                                const {
                                    currentTarget,
                                } = event;
                                const {
                                    value,
                                } = currentTarget;
                                const newFilters = {
                                    ...filters,
                                };
                                newFilters[field] = {
                                    ...newFilters[field],
                                    valueTo: value,
                                };
                                setFilters(newFilters);
                                if (onApplyFilters) {
                                    onApplyFilters(field, newFilters[field]);
                                }
                            } }
                            value={ (filters[field] && filters[field].valueTo) || '' } />
                    }
                </div>
            );
        default: {
            console.warn('NO COMPONENT TYPE'); // eslint-disable-line
            return (
                <div>EMPTY</div>
            );
        }
    }
};

DataTableFloatingFilter.propTypes = {
    agGridReact: PropTypes.object,
    api: PropTypes.object,
    column: PropTypes.object,
    currentParentModel: PropTypes.func,
    filterParams: PropTypes.object,
    frameworkComponentWrapper: PropTypes.object,
    onApplyFilters: PropTypes.func,
    onFloatingFilterChanged: PropTypes.func,
    parentFilterInstance: PropTypes.func,
    reactContainer: PropTypes.object,
    suppressFilterButton: PropTypes.bool,
    filterTypes: PropTypes.shape({
        BOOLEAN: PropTypes.string,
        DATE: PropTypes.string,
        DATETIME: PropTypes.string,
        DECIMAL: PropTypes.string,
        INTEGER: PropTypes.string,
        STRING: PropTypes.string,
        TIME: PropTypes.string,
        YEAR: PropTypes.string,
    }),
};

DataTableFloatingFilter.defaultProps = {};

export default DataTableFloatingFilter;

==> cv-library-react-web-0.1.24.tgz: package/src/components/DataTableFloatingFilter/DataTableFloatingFilter.js <==
import React, { useState } from 'react';
import * as PropTypes from 'prop-types';

import TextField, { INPUT_TYPES } from '../TextField/TextField';
import Toggle from '../Toggle/Toggle';
import DateTimePicker, { DATE_TYPES, DATE_VIEWS } from '../DateTimePicker/DateTimePicker';
import DropDown from '../DropDown/DropDown';

const filterByStringOptions = [
    {
        value: 'equals',
        label: 'Equals',
    },
    {
        value: 'notEqual',
        label: 'Not Equals',
    },
    {
        value: 'contains',
        label: 'Contains',
    },
    {
        value: 'notContains',
        label: 'Not Contains',
    },
    {
        value: 'startsWith',
        label: 'Starts With',
    },
    {
        value: 'endsWith',
        label: 'Ends With',
    },
];
const filterByOptions = [
    {
        value: 'equals',
        label: 'Equals',
    },
    {
        value: 'greaterThan',
        label: 'Greater than',
    },
    {
        value: 'lessThan',
        label: 'Less than',
    },
    {
        value: 'notEqual',
        label: 'Not equal',
    },
    {
        value: 'inRange',
        label: 'In range',
    },
];

const DataTableFloatingFilter = (props) => {
    console.log('DATA TABLE FLOATING FILTER PROPS: ', props); // eslint-disable-line

    const {
        column,
        onApplyFilters,
        filterTypes: FILTER_TYPES,
    } = props;
    const {
        colDef,
    } = column;
    const {
        field,
        filterType,
    } = colDef;
    const [
        filters,
        setFilters,
    ] = useState({});
    let type = FILTER_TYPES.STRING;
    if (filterType) {
        type = filterType.toUpperCase();
    }

    // Default to text input type
    let textFieldType = INPUT_TYPES.TEXT;
    let stringCriteria = filterByStringOptions;

    // Default to DateTime date input type, format and views
    let dateFieldType = DATE_TYPES.DATETIME;
    let dateFieldFormat = 'M/dd/yy, h:mm a';
    let dateTimeViews = [
        DATE_VIEWS.DATE,
        DATE_VIEWS.HOURS,
        DATE_VIEWS.MINUTES,
        DATE_VIEWS.YEAR,
    ];
    const useRange = filters[field] && filters[field].criteria === 'inRange';

    switch (type) {
        case FILTER_TYPES.BOOLEAN:
            return (
                <Toggle
                    checked={ !!filters[field] || false }
                    onChange={ (event) => {
                        const {
                            currentTarget,
                        } = event;
                        const {
                            checked,
                        } = currentTarget;
                        setFilters({
                            ...filters,
                            [field]: checked,
                        });
                        if (onApplyFilters) {
                            onApplyFilters(field, checked);
                        }
                    } } />
            );

        case FILTER_TYPES.DATE:
            if (type === FILTER_TYPES.DATE) {
                dateFieldType = DATE_TYPES.DATE;
                dateFieldFormat = 'M/dd/yy';
                dateTimeViews = [
                    DATE_VIEWS.DATE,
                    DATE_VIEWS.YEAR,
                ];
            }
        // eslint-disable-next-line no-fallthrough
        case FILTER_TYPES.YEAR:
            if (type === FILTER_TYPES.YEAR) {
                dateFieldType = DATE_TYPES.DATE;
                dateFieldFormat = 'yyyy';
                dateTimeViews = [ DATE_VIEWS.YEAR ];
            }
        // eslint-disable-next-line no-fallthrough
        case FILTER_TYPES.TIME:
            if (type === FILTER_TYPES.TIME) {
                dateFieldType = DATE_TYPES.TIME;
                dateFieldFormat = 'h:mm a';
                dateTimeViews = [
                    DATE_VIEWS.HOURS,
                    DATE_VIEWS.MINUTES,
                ];
            }
        // eslint-disable-next-line no-fallthrough
        case FILTER_TYPES.DATETIME:
            return (
                <div style={ {
                    display: 'flex',
                    flexDirection: 'column',
                } }>
                    <DropDown
                        items={ filterByOptions }
                        onChange={ (event, props) => {
                            const {
                                target,
                            } = event;
                            const {
                                value,
                            } = target;
                            const {
                                text,
                            } = props;
                            const newFilters = {
                                ...filters,
                            };
                            newFilters[field] = {
                                ...newFilters[field],
                                criteria: value,
                                text,
                            };
                            setFilters(newFilters);
                            if (onApplyFilters) {
                                onApplyFilters(field, newFilters[field]);
                            }
                        } }
                        renderValue={ (value) => (value || 'Filter type...') }
                        renderItem={ (MenuItem, item) => (
                            <MenuItem
                                value={ item.value }
                                text={ item.label }
                                key={ item.value } />
                        ) }
                        value={ (filters[field] && filters[field].text) || '' } />
                    <DateTimePicker
                        emptyLabel={ useRange ? 'Filter from...' : 'Filter date...' }
                        selectedDate={ useRange ? (filters[field].valueFrom || null) : ((filters[field] && filters[field].value) || null) }
                        onChange={ (value) => {
                            const newFilters = {
                                ...filters,
                            };
                            if (useRange) {
                                newFilters[field] = {
                                    ...newFilters[field],
                                    valueFrom: value,
                                };
                            }
                            else {
                                newFilters[field] = {
                                    ...newFilters[field],
                                    value,
                                };
                            }
                            setFilters(newFilters);
                            if (onApplyFilters) {
                                onApplyFilters(field, newFilters[field]);
                            }
                        } }
                        format={ dateFieldFormat }
                        mode={ dateFieldType }
                        views={ dateTimeViews } />
                    { useRange &&
                        <DateTimePicker
                            emptyLabel="Filter to..."
                            selectedDate={ (filters[field] && filters[field].valueTo) || null }
                            onChange={ (value) => {
                                const newFilters = {
                                    ...filters,
                                };
                                if (useRange) {
                                    newFilters[field] = {
                                        ...newFilters[field],
                                        valueTo: value,
                                    };
                                }
                                else {
                                    newFilters[field] = {
                                        ...newFilters[field],
                                        value,
                                    };
                                }
                                setFilters(newFilters);
                                if (onApplyFilters) {
                                    onApplyFilters(field, newFilters[field]);
                                }
                            } }
                            format={ dateFieldFormat }
                            mode={ dateFieldType }
                            views={ dateTimeViews } />
                    }
                </div>
            );

        case FILTER_TYPES.DECIMAL:
            if (type === FILTER_TYPES.DECIMAL) {
                textFieldType = INPUT_TYPES.NUMBER;
                stringCriteria = filterByOptions;
            }
        // eslint-disable-next-line no-fallthrough
        case FILTER_TYPES.INTEGER:
            if (type === FILTER_TYPES.INTEGER) {
                textFieldType = INPUT_TYPES.NUMBER;
                stringCriteria = filterByOptions;
            }
        // eslint-disable-next-line no-fallthrough
        case FILTER_TYPES.STRING:
            return (
                <div style={ {
                    display: 'flex',
                    flexDirection: 'column',
                } }>
                    <DropDown
                        items={ stringCriteria }
                        onChange={ (event, props) => {
                            const {
                                target,
                            } = event;
                            const {
                                value,
                            } = target;
                            const {
                                text,
                            } = props;
                            const newFilters = {
                                ...filters,
                            };
                            newFilters[field] = {
                                ...newFilters[field],
                                criteria: value,
                                text,
                            };
                            setFilters(newFilters);
                            if (onApplyFilters) {
                                onApplyFilters(field, newFilters[field]);
                            }
                        } }
                        renderValue={ (value) => (value || 'Filter type...') }
                        renderItem={ (MenuItem, item) => (
                            <MenuItem
                                value={ item.value }
                                text={ item.label }
                                key={ item.value } />
                        ) }
                        value={ (filters[field] && filters[field].text) || '' } />
                    <TextField
                        placeholder={ useRange ? 'Filter from...' : 'Filter text...' }
                        type={ textFieldType }
                        onChange={ (event) => {
                            const {
                                currentTarget,
                            } = event;
                            const {
                                value,
                            } = currentTarget;
                            const newFilters = {
                                ...filters,
                            };
                            if (useRange) {
                                newFilters[field] = {
                                    ...newFilters[field],
                                    valueFrom: value,
                                };
                            }
                            else {
                                newFilters[field] = {
                                    ...newFilters[field],
                                    value,
                                };
                            }
                            setFilters(newFilters);
                            if (onApplyFilters) {
                                onApplyFilters(field, newFilters[field]);
                            }
                        } }
                        value={ useRange ? (filters[field].valueFrom || '') : ((filters[field] && filters[field].value) || '') } />
                    { useRange &&
                        <TextField
                            placeholder="Filter to..."
                            type={ textFieldType }
                            onChange={ (event) => {
                                const {
                                    currentTarget,
                                } = event;
                                const {
                                    value,
                                } = currentTarget;
                                const newFilters = {
                                    ...filters,
                                };
                                newFilters[field] = {
                                    ...newFilters[field],
                                    valueTo: value,
                                };
                                setFilters(newFilters);
                                if (onApplyFilters) {
                                    onApplyFilters(field, newFilters[field]);
                                }
                            } }
                            value={ (filters[field] && filters[field].valueTo) || '' } />
                    }
                </div>
            );
        default: {
            console.warn('NO COMPONENT TYPE'); // eslint-disable-line
            return (
                <div>EMPTY</div>
            );
        }
    }
};

DataTableFloatingFilter.propTypes = {
    agGridReact: PropTypes.object,
    api: PropTypes.object,
    column: PropTypes.object,
    currentParentModel: PropTypes.func,
    filterParams: PropTypes.object,
    frameworkComponentWrapper: PropTypes.object,
    onApplyFilters: PropTypes.func,
    onFloatingFilterChanged: PropTypes.func,
    parentFilterInstance: PropTypes.func,
    reactContainer: PropTypes.object,
    suppressFilterButton: PropTypes.bool,
    filterTypes: PropTypes.shape({
        BOOLEAN: PropTypes.string,
        DATE: PropTypes.string,
        DATETIME: PropTypes.string,
        DECIMAL: PropTypes.string,
        INTEGER: PropTypes.string,
        STRING: PropTypes.string,
        TIME: PropTypes.string,
        YEAR: PropTypes.string,
    }),
};

DataTableFloatingFilter.defaultProps = {};

export default DataTableFloatingFilter;
